<!--- This file has been generated from an external template. Please do not modify it directly. -->
<!--- Changes should be contributed to https://github.com/munich-quantum-toolkit/templates. -->

# Support

If you are stuck with a problem using MQT Bench or have questions, please get in touch at our [Issues] or [Discussions].
We'd love to help.

You can save time by following this procedure when reporting a problem:

- Do try to solve the problem on your own first.
- Search through past [Issues] and [Discussions] to see if someone else already had the same problem.
- Before filing a bug report, try to create a minimal reproducible example (MRE) that reproduces the problem.
  It is much easier to identify the cause for the problem if a handful of lines suffice to show that something is not working.

You can also always reach us at [quantum.cda@xcit.tum.de](mailto:quantum.cda@xcit.tum.de).

[Issues]: https://github.com/munich-quantum-toolkit/bench/issues
[Discussions]: https://github.com/munich-quantum-toolkit/bench/discussions
